validate_genes: Validate the proper relationship between the genes of output,...

Description Usage

View source: R/extension.R

Description

Validate the proper relationship between the genes of output, motif, and RG.

Usage

1
validate_genes(bn_motif, rg_large, output_genes)

VladoBaca/BNRewiringRobustness documentation built on Jan. 25, 2022, 11:51 p.m.